@@ -2,9 +2,9 @@
 
 """`jict` provides dictionaries with multiple levels of nested-ness."""
 
-__version__ = '2.5.6'
-from .jict import jict, sqlconnect
-from .helpers import evaluate
+__version__ = '2.6'
+from .jict import jict
+from .helpers import evaluate , sqlconnect
 from collections import deque
 
 try:
