@@ -6,6 +6,7 @@ from collections import defaultdict , deque
 import sys, json, yaml, os, random, re ,copy, importlib, mmap
 from bson.objectid import ObjectId
 from time import time
+from datetime import timedelta as td, datetime as dt
 
 from pymongo.collection import Collection as mgcoll
 nolibs = []
@@ -27,21 +28,6 @@ class JSONEncoder(json.JSONEncoder):
         except:
             return str(o)
 
-def sqlconnect(str):
-    if 'mysql-connector' in nolibs:
-        raise Exception('strore sql rquieres \'mysql-connector\' module')
-
-    user,pawd,host,database = re.findall(
-        "(.*):(.*)@([0-9]{0,3}.[0-9]{0,3}.[0-9]{0,3}.[0-9]{0,3}):(.*)"
-    , str )[0]
-    cnt = mysql.connector.connect(
-        host=host,
-        database=database,
-        user=user,
-        password=pawd
-    )
-    return cnt
-
 def loader(nd):
     nam, ext = os.path.splitext( nd )
 
@@ -120,6 +106,17 @@ class jict( defaultdict ):
 
                     dt = to_jict( loader(nd) )
                     dt.storepath = nd
+
+                elif nd[-5:] == '.list':
+                    file = open( nd, "r+" )
+                    text = file.read()
+                    file.close()
+                    ls = []
+                    for x in text.split('\n'):
+                        if x == '': continue
+                        ls.append(x)
+
+                    return ls
                 elif nd[-4:] == '.env' or '.env.example' in nd:
                     file = open( nd, "r+" )
                     text = file.read()
@@ -186,6 +183,8 @@ class jict( defaultdict ):
                     return str(self[key])
                 elif format == float:
                     return float(self[key])
+                elif format == list:
+                    return []
             except:
                 pass
 
@@ -193,6 +192,14 @@ class jict( defaultdict ):
         self[key] = deft
         return self[key]
 
+    def strptime(self,key,pattern):
+        return dt.strptime( self[key] ,pattern )
+
+    def strptimestamp(self,key,pattern):
+        if key not in self:
+            return None
+        return dt.timestamp( dt.strptime( self[key] ,pattern ) )
+
     def __iadd__(self, other):
         typ = type(other)
 
@@ -238,7 +245,7 @@ class jict( defaultdict ):
         self[key] = val if val < self[key] else self[key]
         return self[key]
 
-    def drop(self ,target = None, as_type=''):
+    def drop(self ,target = None, as_type='', deep = False ):
 
         def ittrlis(val,tar):
             for l in val:
@@ -252,6 +259,15 @@ class jict( defaultdict ):
             if isinstance(val , jict):
                 val.drop( target )
 
+                if deep:
+                    skp = False
+                    for y in val:
+                        if val[y] != target:
+                            skp = True; break
+                    if not skp:
+                        del self[x]
+                        continue
+
             if isinstance(val , list ):
                 ittrlis(val, target)
 
